==> selenium-selenium-4.40.0.gh.tar.gz: selenium-selenium-4.40.0/java/src/org/openqa/selenium/bidi/emulation/ScreenOrientation.java <==
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.openqa.selenium.bidi.emulation;

import java.util.Map;
import org.openqa.selenium.internal.Require;

public class ScreenOrientation {
  private final ScreenOrientationNatural natural;
  private final ScreenOrientationType type;

  public ScreenOrientation(ScreenOrientationNatural natural, ScreenOrientationType type) {
    this.natural = Require.nonNull("natural", natural);
    this.type = Require.nonNull("type", type);
  }

  public ScreenOrientationNatural getNatural() {
    return natural;
  }

  public ScreenOrientationType getType() {
    return type;
  }

  public Map<String, Object> toMap() {
    return Map.of(
        "natural", natural.toString(),
        "type", type.toString());
  }
}

==> selenium-selenium-4.41.0.gh.tar.gz: selenium-selenium-4.41.0/java/src/org/openqa/selenium/bidi/emulation/ScreenOrientation.java <==
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.openqa.selenium.bidi.emulation;

import java.util.Map;
import org.openqa.selenium.internal.Require;

public class ScreenOrientation {
  private final ScreenOrientationNatural natural;
  private final ScreenOrientationType type;

  public ScreenOrientation(ScreenOrientationNatural natural, ScreenOrientationType type) {
    this.natural = Require.nonNull("natural", natural);
    this.type = Require.nonNull("type", type);
  }

  public ScreenOrientationNatural getNatural() {
    return natural;
  }

  public ScreenOrientationType getType() {
    return type;
  }

  public Map<String, Object> toMap() {
    return Map.of(
        "natural", natural.toString(),
        "type", type.toString());
  }

  @Override
  public String toString() {
    return String.format("ScreenOrientation{natural=%s, type=%s}", natural, type);
  }
}
